@@ -23,8 +23,9 @@ from mistralclient.tests.unit import base
 WORKBOOK_DICT = {
     'name': 'a',
     'tags': ['a', 'b'],
+    'scope': 'private',
     'created_at': '1',
-    'updated_at': '1'
+    'updated_at': '1',
 }
 
 
@@ -54,7 +55,26 @@ class TestCLIWorkbooksV2(base.BaseCommandTest):
 
         result = self.call(workbook_cmd.Create, app_args=['wb.yaml'])
 
-        self.assertEqual(('a', 'a, b', '1', '1'), result[1])
+        self.assertEqual(('a', 'a, b', 'private', '1', '1'), result[1])
+
+    @mock.patch('argparse.open', create=True)
+    def test_create_public(self, mock_open):
+        wb_public_dict = WORKBOOK_DICT.copy()
+        wb_public_dict['scope'] = 'public'
+        workbook_public = workbooks.Workbook(mock, wb_public_dict)
+        self.client.workbooks.create.return_value = workbook_public
+
+        result = self.call(
+            workbook_cmd.Create,
+            app_args=['wb.yaml', '--public']
+        )
+
+        self.assertEqual(('a', 'a, b', 'public', '1', '1'), result[1])
+
+        self.assertEqual(
+            'public',
+            self.client.workbooks.create.call_args[1]['scope']
+        )
 
     @mock.patch('argparse.open', create=True)
     def test_update(self, mock_open):
@@ -62,21 +82,40 @@ class TestCLIWorkbooksV2(base.BaseCommandTest):
 
         result = self.call(workbook_cmd.Update, app_args=['definition'])
 
-        self.assertEqual(('a', 'a, b', '1', '1'), result[1])
+        self.assertEqual(('a', 'a, b', 'private', '1', '1'), result[1])
+
+    @mock.patch('argparse.open', create=True)
+    def test_update_public(self, mock_open):
+        wb_public_dict = WORKBOOK_DICT.copy()
+        wb_public_dict['scope'] = 'public'
+        workbook_public = workbooks.Workbook(mock, wb_public_dict)
+        self.client.workbooks.update.return_value = workbook_public
+
+        result = self.call(
+            workbook_cmd.Update,
+            app_args=['definition', '--public']
+        )
+
+        self.assertEqual(('a', 'a, b', 'public', '1', '1'), result[1])
+
+        self.assertEqual(
+            'public',
+            self.client.workbooks.update.call_args[1]['scope']
+        )
 
     def test_list(self):
-        self.client.workbooks.list.return_value = (WORKBOOK,)
+        self.client.workbooks.list.return_value = [WORKBOOK]
 
         result = self.call(workbook_cmd.List)
 
-        self.assertEqual([('a', 'a, b', '1', '1')], result[1])
+        self.assertEqual([('a', 'a, b', 'private', '1', '1')], result[1])
 
     def test_get(self):
         self.client.workbooks.get.return_value = WORKBOOK
 
         result = self.call(workbook_cmd.Get, app_args=['name'])
 
-        self.assertEqual(('a', 'a, b', '1', '1'), result[1])
+        self.assertEqual(('a', 'a, b', 'private', '1', '1'), result[1])
 
     def test_delete(self):
         self.call(workbook_cmd.Delete, app_args=['name'])
